package
Version:
v0.0.0-...-82b0641
Opens a new window with list of versions in this module.
Published: Dec 11, 2021
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
- Constants
-
func Debug(v ...interface{})
-
func Debugf(format string, v ...interface{})
-
func Error(v ...interface{})
-
func Errorf(format string, v ...interface{})
-
func Fatal(v ...interface{})
-
func Fatalf(format string, v ...interface{})
-
func GetLogger() log.Logger
-
func Info(v ...interface{})
-
func Infof(format string, v ...interface{})
-
func Log(v ...interface{})
-
func Logf(format string, v ...interface{})
-
func Name(name string)
-
func SetLevel(l Level)
-
func SetLogger(l log.Logger)
-
func SetPrefix(p string)
-
func Trace(v ...interface{})
-
func Tracef(format string, v ...interface{})
-
func Warn(v ...interface{})
-
func Warnf(format string, v ...interface{})
-
func WithLevel(l Level, v ...interface{})
-
func WithLevelf(l Level, format string, v ...interface{})
-
type Level
const (
StarkLogLevel = "STARK_LOG_LEVEL"
)
func Debug(v ...interface{})
Debug provides debug level logging
func Debugf(format string, v ...interface{})
Debugf provides debug level logging
func Error(v ...interface{})
Error provides warn level logging
func Errorf(format string, v ...interface{})
Errorf provides warn level logging
func Fatal(v ...interface{})
Fatal logs with Log and then exits with os.Exit(1)
func Fatalf(format string, v ...interface{})
Fatalf logs with Logf and then exits with os.Exit(1)
GetLogger returns the local logger
func Info(v ...interface{})
Info provides info level logging
func Infof(format string, v ...interface{})
Infof provides info level logging
func Log(v ...interface{})
Log makes use of github.com/go-log/log.Log
func Logf(format string, v ...interface{})
Logf makes use of github.com/go-log/log.Logf
SetLevel sets the log level
SetLogger sets the local logger
Set a prefix for the logger
func Trace(v ...interface{})
Trace provides trace level logging
func Tracef(format string, v ...interface{})
Tracef provides trace level logging
func Warn(v ...interface{})
Warn provides warn level logging
func Warnf(format string, v ...interface{})
Warnf provides warn level logging
func WithLevel(l Level, v ...interface{})
WithLevel logs with the level specified
func WithLevelf(l Level, format string, v ...interface{})
WithLevel logs with the level specified
const (
LevelFatal Level = iota
LevelError
LevelInfo
LevelWarn
LevelDebug
LevelTrace
)
GetLevel returns the current level
Source Files
¶
Click to show internal directories.
Click to hide internal directories.